summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--.github/workflows/ccpp.yml95
-rw-r--r--.github/workflows/fuzz.yml2
-rw-r--r--.github/workflows/linux.yml159
-rw-r--r--.github/workflows/macosx.yml61
-rw-r--r--.travis.yml7
-rw-r--r--ACE/ACE-INSTALL.html19
-rw-r--r--ACE/COPYING44
-rw-r--r--ACE/PROBLEM-REPORT-FORM12
-rw-r--r--ACE/README2
-rw-r--r--ACE/ace/Basic_Types.h2
-rw-r--r--ACE/ace/OS_NS_Thread.cpp11
-rw-r--r--ACE/ace/Object_Manager.cpp1
-rw-r--r--ACE/ace/Object_Manager.h2
-rw-r--r--ACE/ace/Process_Manager.cpp30
-rw-r--r--ACE/ace/SSL/SSL_Asynch_Stream.cpp7
-rw-r--r--ACE/ace/SSL/SSL_Asynch_Stream.h2
-rw-r--r--ACE/ace/SSL/SSL_Context.cpp11
-rw-r--r--ACE/ace/SSL/SSL_SOCK.h3
-rw-r--r--ACE/ace/SSL/SSL_SOCK_Acceptor.cpp1
-rw-r--r--ACE/ace/SSL/SSL_SOCK_Acceptor.h4
-rw-r--r--ACE/ace/SSL/SSL_SOCK_Connector.h7
-rw-r--r--ACE/ace/SSL/SSL_SOCK_Stream.cpp1
-rw-r--r--ACE/ace/SSL/SSL_SOCK_Stream.h48
-rw-r--r--ACE/ace/SSL/SSL_SOCK_Stream.inl1
-rw-r--r--ACE/ace/config-android.h8
-rw-r--r--ACE/ace/config-win32-common.h1
-rw-r--r--ACE/ace/os_include/net/os_if.h2
-rwxr-xr-xACE/bin/ace-install64
-rw-r--r--ACE/examples/IPC_SAP/SSL_SAP/README2
-rw-r--r--ACE/examples/IPC_SAP/SSL_SAP/SSL-client-simple.h2
-rw-r--r--ACE/examples/IPC_SAP/SSL_SAP/SSL-client.h49
-rw-r--r--ACE/examples/IPC_SAP/SSL_SAP/SSL-server-simple.cpp5
-rw-r--r--ACE/examples/IPC_SAP/SSL_SAP/SSL-server.cpp5
-rw-r--r--ACE/tests/Compiler_Features_13_Test.cpp13
-rw-r--r--ACE/tests/Network_Adapters_Test.cpp4
-rw-r--r--ACE/tests/Process_Env_Test.cpp24
-rw-r--r--ACE/tests/SSL/Bug_2912_Regression_Test.cpp1
-rw-r--r--ACE/tests/SSL/Thread_Pool_Reactor_SSL_Test.cpp5
-rw-r--r--ACE/tests/SSL/Thread_Pool_Reactor_SSL_Test.h6
-rw-r--r--ACE/tests/tests.mpc9
-rw-r--r--TAO/PROBLEM-REPORT-FORM10
-rw-r--r--TAO/TAO-INSTALL.html2
-rw-r--r--TAO/TAO_IDL/util/utl_global.cpp112
-rw-r--r--TAO/orbsvcs/orbsvcs/SSLIOP/SSLIOP_Factory.cpp2
-rw-r--r--TAO/orbsvcs/tests/Concurrency/CC_command.tab.cpp2
-rw-r--r--TAO/orbsvcs/tests/Concurrency/lex.CC_command.cpp42
-rw-r--r--azure-pipelines.yml97
47 files changed, 489 insertions, 510 deletions
diff --git a/.github/workflows/ccpp.yml b/.github/workflows/ccpp.yml
deleted file mode 100644
index 6d08a1b7518..00000000000
--- a/.github/workflows/ccpp.yml
+++ /dev/null
@@ -1,95 +0,0 @@
-name: C/C++ CI
-
-on:
- push:
- pull_request:
- schedule:
- - cron: '0 7 * * SUN'
-
-jobs:
- build:
- runs-on: ubuntu-latest
- strategy:
- matrix:
- name: [
- GCC48,
- GCC6,
- GCC7,
- GCC8,
- GCC9
- ]
- include:
- - name: GCC48
- CC: gcc-4.8
- CXX: g++-4.8
- PackageDeps: g++-4.8
- - name: GCC6
- CC: gcc-6
- CXX: g++-6
- PackageDeps: g++-6
- - name: GCC7
- CC: gcc-7
- CXX: g++-7
- PackageDeps: g++-7
- - name: GCC8
- CC: gcc-8
- CXX: g++-8
- PackageDeps: g++-8
- - name: GCC9
- CC: gcc-9
- CXX: g++-9
- PackageDeps: g++-9
- env:
- ACE_ROOT: ${{ github.workspace }}/ACE
- TAO_ROOT: ${{ github.workspace }}/TAO
- MPC_ROOT: ${{ github.workspace }}/../MPC
- CC: ${{ matrix.CC }}
- CXX: ${{ matrix.CXX }}
- steps:
- - name: checkout ACE/TAO
- uses: actions/checkout@v1
- - name: checkout MPC
- uses: actions/checkout@v1
- with:
- repository: DOCGroup/MPC
- ref: master
- fetch-depth: 1
- - name: Add packages
- run: |
- sudo apt-get --yes update
- sudo apt-get --yes install libxerces-c-dev libssl-dev ${{ matrix.PackageDeps }}
- - name: create $ACE_ROOT/ace/config.h
- run: |
- '#include "ace/config-linux.h"' > ${env:ACE_ROOT}/ace/config.h
- shell: pwsh
- - name: create $ACE_ROOT/include/makeinclude/platform_macros.GNU
- run: |
- 'ipv6=1' > ${env:ACE_ROOT}/include/makeinclude/platform_macros.GNU
- 'xerces3=1' >> ${env:ACE_ROOT}/include/makeinclude/platform_macros.GNU
- 'ssl=1' >> ${env:ACE_ROOT}/include/makeinclude/platform_macros.GNU
- 'c++11=1' >> ${env:ACE_ROOT}/include/makeinclude/platform_macros.GNU
- 'include $(ACE_ROOT)/include/makeinclude/platform_linux.GNU' >> ${env:ACE_ROOT}/include/makeinclude/platform_macros.GNU
- shell: pwsh
- - name: create $ACE_ROOT/bin/MakeProjectCreator/config/default.features
- run: |
- 'ipv6=1' > ${env:ACE_ROOT}/bin/MakeProjectCreator/config/default.features
- 'xerces3=1' >> ${env:ACE_ROOT}/bin/MakeProjectCreator/config/default.features
- 'ssl=1' >> ${env:ACE_ROOT}/bin/MakeProjectCreator/config/default.features
- 'versioned_namespace=1' >> ${env:ACE_ROOT}/bin/MakeProjectCreator/config/default.features
- shell: pwsh
- - name: Run mwc.pl on $(TAO_ROOT)/TAO_ACE.mwc
- run: |
- perl ${env:ACE_ROOT}/bin/mwc.pl -type gnuace ${env:TAO_ROOT}/TAO_ACE.mwc -workers 4
- shell: pwsh
- - name: Run mwc.pl on $(ACE_ROOT)/tests/tests.mwc
- run: |
- perl ${env:ACE_ROOT}/bin/mwc.pl -type gnuace ${env:ACE_ROOT}/tests/tests.mwc -workers 4
- shell: pwsh
- - name: Build TAO_ACE project
- run: |
- make -j 6 -C ${env:TAO_ROOT}
- shell: pwsh
- - name: Build ACE/tests project
- run: |
- make -j 6 -C ${env:ACE_ROOT}/tests
- shell: pwsh
diff --git a/.github/workflows/fuzz.yml b/.github/workflows/fuzz.yml
index 011e9b82074..e95d3d50182 100644
--- a/.github/workflows/fuzz.yml
+++ b/.github/workflows/fuzz.yml
@@ -15,7 +15,7 @@ jobs:
steps:
- name: checkout ACE/TAO
- uses: actions/checkout@v1
+ uses: actions/checkout@v2
- name: Run fuzz
run: |
perl ${env:ACE_ROOT}/bin/fuzz.pl
diff --git a/.github/workflows/linux.yml b/.github/workflows/linux.yml
new file mode 100644
index 00000000000..b7b7a860f45
--- /dev/null
+++ b/.github/workflows/linux.yml
@@ -0,0 +1,159 @@
+name: linux
+
+on:
+ push:
+ pull_request:
+ schedule:
+ - cron: '0 7 * * SUN'
+
+jobs:
+ build:
+ strategy:
+ matrix:
+ name: [
+ GCC48,
+ GCC6,
+ GCC7,
+ GCC8,
+ GCC9,
+ GCC10,
+ CLANG5,
+ CLANG6,
+ CLANG7,
+ CLANG8,
+ CLANG9,
+ CLANG10
+ ]
+ include:
+ - name: GCC48
+ CC: gcc-4.8
+ CXX: g++-4.8
+ PackageDeps: g++-4.8
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux.GNU
+ imagename: ubuntu-16.04
+ - name: GCC6
+ CC: gcc-6
+ CXX: g++-6
+ PackageDeps: g++-6
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux.GNU
+ imagename: ubuntu-18.04
+ - name: GCC7
+ CC: gcc-7
+ CXX: g++-7
+ PackageDeps: g++-7
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux.GNU
+ imagename: ubuntu-18.04
+ - name: GCC8
+ CC: gcc-8
+ CXX: g++-8
+ PackageDeps: g++-8
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux.GNU
+ imagename: ubuntu-18.04
+ - name: GCC9
+ CC: gcc-9
+ CXX: g++-9
+ PackageDeps: g++-9
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux.GNU
+ imagename: ubuntu-18.04
+ - name: GCC10
+ CC: gcc-10
+ CXX: g++-10
+ PackageDeps: g++-10
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux.GNU
+ imagename: ubuntu-18.04
+ - name: CLANG5
+ CC: clang-5.0
+ CXX: clang++-5.0
+ PackageDeps: clang-5.0
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux_clang.GNU
+ imagename: ubuntu-16.04
+ - name: CLANG6
+ CC: clang-6.0
+ CXX: clang++-6.0
+ PackageDeps: clang-6.0
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux_clang.GNU
+ imagename: ubuntu-18.04
+ - name: CLANG7
+ CC: clang-7
+ CXX: clang++-7
+ PackageDeps: clang-7
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux_clang.GNU
+ imagename: ubuntu-18.04
+ - name: CLANG8
+ CC: clang-8
+ CXX: clang++-8
+ PackageDeps: clang-8
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux_clang.GNU
+ imagename: ubuntu-18.04
+ - name: CLANG9
+ CC: clang-9
+ CXX: clang++-9
+ PackageDeps: clang-9
+ Repo: llvm-toolchain-$(lsb_release -cs)-9
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux_clang.GNU
+ imagename: ubuntu-18.04
+ - name: CLANG10
+ CC: clang-10
+ CXX: clang++-10
+ PackageDeps: clang-10
+ Repo: llvm-toolchain-$(lsb_release -cs)-10
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux_clang.GNU
+ imagename: ubuntu-18.04
+ runs-on: ${{ matrix.imagename }}
+ env:
+ ACE_ROOT: ${{ github.workspace }}/ACE
+ TAO_ROOT: ${{ github.workspace }}/TAO
+ MPC_ROOT: ${{ github.workspace }}/MPC
+ CC: ${{ matrix.CC }}
+ CXX: ${{ matrix.CXX }}
+ steps:
+ - name: checkout ACE/TAO
+ uses: actions/checkout@v2
+ - name: checkout MPC
+ uses: actions/checkout@v2
+ with:
+ repository: DOCGroup/MPC
+ path: MPC
+ - name: Add Repo
+ run: |
+ wget -O - https://apt.llvm.org/llvm-snapshot.gpg.key|sudo apt-key add -
+ sudo apt-add-repository "deb http://apt.llvm.org/$(lsb_release -cs)/ ${{ matrix.Repo }} main"
+ if: matrix.Repo != ''
+ - name: Add packages
+ run: |
+ sudo apt-get --yes update
+ sudo apt-get --yes install libxerces-c-dev libssl-dev ${{ matrix.PackageDeps }}
+ - name: create $ACE_ROOT/ace/config.h
+ run: |
+ '#include "ace/config-linux.h"' > ${env:ACE_ROOT}/ace/config.h
+ shell: pwsh
+ - name: create $ACE_ROOT/include/makeinclude/platform_macros.GNU
+ run: |
+ 'ipv6=1' > ${env:ACE_ROOT}/include/makeinclude/platform_macros.GNU
+ 'xerces3=1' >> ${env:ACE_ROOT}/include/makeinclude/platform_macros.GNU
+ 'ssl=1' >> ${env:ACE_ROOT}/include/makeinclude/platform_macros.GNU
+ '${{ matrix.platform_file }}' >> ${env:ACE_ROOT}/include/makeinclude/platform_macros.GNU
+ shell: pwsh
+ - name: create $ACE_ROOT/bin/MakeProjectCreator/config/default.features
+ run: |
+ 'ipv6=1' > ${env:ACE_ROOT}/bin/MakeProjectCreator/config/default.features
+ 'xerces3=1' >> ${env:ACE_ROOT}/bin/MakeProjectCreator/config/default.features
+ 'ssl=1' >> ${env:ACE_ROOT}/bin/MakeProjectCreator/config/default.features
+ 'versioned_namespace=1' >> ${env:ACE_ROOT}/bin/MakeProjectCreator/config/default.features
+ shell: pwsh
+ - name: Run mwc.pl on $(TAO_ROOT)/TAO_ACE.mwc
+ run: |
+ perl ${env:ACE_ROOT}/bin/mwc.pl -type gnuace ${env:TAO_ROOT}/TAO_ACE.mwc -workers 4
+ shell: pwsh
+ - name: Run mwc.pl on $(ACE_ROOT)/tests/tests.mwc
+ run: |
+ perl ${env:ACE_ROOT}/bin/mwc.pl -type gnuace ${env:ACE_ROOT}/tests/tests.mwc -workers 4
+ shell: pwsh
+ - name: Build TAO_ACE project
+ run: |
+ make -j 6 -C ${env:TAO_ROOT}
+ shell: pwsh
+ - name: Build ACE/tests project
+ run: |
+ make -j 6 -C ${env:ACE_ROOT}/tests
+ shell: pwsh
diff --git a/.github/workflows/macosx.yml b/.github/workflows/macosx.yml
new file mode 100644
index 00000000000..1164edebe9d
--- /dev/null
+++ b/.github/workflows/macosx.yml
@@ -0,0 +1,61 @@
+name: macosx
+
+on:
+ push:
+ pull_request:
+ schedule:
+ - cron: '0 7 * * SUN'
+
+jobs:
+ build:
+ strategy:
+ matrix:
+ name: [
+ macos1015
+ ]
+ include:
+ - name: macos1015
+ platform_file: include $(ACE_ROOT)/include/makeinclude/platform_macosx.GNU
+ imagename: macos-10.15
+ runs-on: ${{ matrix.imagename }}
+ env:
+ ACE_ROOT: ${{ github.workspace }}/ACE
+ TAO_ROOT: ${{ github.workspace }}/TAO
+ MPC_ROOT: ${{ github.workspace }}/MPC
+ steps:
+ - name: checkout ACE/TAO
+ uses: actions/checkout@v2
+ - name: checkout MPC
+ uses: actions/checkout@v2
+ with:
+ repository: DOCGroup/MPC
+ path: MPC
+ - name: create $ACE_ROOT/ace/config.h
+ run: |
+ '#include "ace/config-macosx.h"' > ${env:ACE_ROOT}/ace/config.h
+ shell: pwsh
+ - name: create $ACE_ROOT/include/makeinclude/platform_macros.GNU
+ run: |
+ '${{ matrix.platform_file }}' > ${env:ACE_ROOT}/include/makeinclude/platform_macros.GNU
+ shell: pwsh
+ - name: create $ACE_ROOT/bin/MakeProjectCreator/config/default.features
+ run: |
+ 'ipv6=1' > ${env:ACE_ROOT}/bin/MakeProjectCreator/config/default.features
+ 'versioned_namespace=1' >> ${env:ACE_ROOT}/bin/MakeProjectCreator/config/default.features
+ shell: pwsh
+ - name: Run mwc.pl on $(TAO_ROOT)/TAO_ACE.mwc
+ run: |
+ perl ${env:ACE_ROOT}/bin/mwc.pl -type gnuace ${env:TAO_ROOT}/TAO_ACE.mwc -workers 4
+ shell: pwsh
+ - name: Run mwc.pl on $(ACE_ROOT)/tests/tests.mwc
+ run: |
+ perl ${env:ACE_ROOT}/bin/mwc.pl -type gnuace ${env:ACE_ROOT}/tests/tests.mwc -workers 4
+ shell: pwsh
+ - name: Build TAO_ACE project
+ run: |
+ make -j 6 -C ${env:TAO_ROOT}
+ shell: pwsh
+ - name: Build ACE/tests project
+ run: |
+ make -j 6 -C ${env:ACE_ROOT}/tests
+ shell: pwsh
diff --git a/.travis.yml b/.travis.yml
index ba54aba53d0..536f8d02bcc 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -12,9 +12,7 @@ env:
- CORBAEMICRO=1 ACEFORTAO=0 TAO=1
- CORBAECOMPACT=1 ACEFORTAO=0 TAO=1
- ACEFORTAO=1 TAO=1
- - ACETESTS=1 ACEFORTAO=0 ACE=1 TAO=0
- USES_WCHAR=1 TAO=1
- - VERSIONED=1 TAO=1
- ACETESTS=1 FACE=1 ACE=1 TAO=0
global:
- ACE_ROOT=$TRAVIS_BUILD_DIR/ACE
@@ -23,11 +21,6 @@ env:
- LD_LIBRARY_PATH=$ACE_ROOT/lib:$LD_LIBRARY_PATH
- COMPILER=g++-8
-matrix:
- include:
- - os: osx
- env: COMPILER=clang++ VERSIONED=1 TAO=1 ACETESTS=1
-
addons:
apt:
packages:
diff --git a/ACE/ACE-INSTALL.html b/ACE/ACE-INSTALL.html
index 2cd45ae6a09..c05056712f4 100644
--- a/ACE/ACE-INSTALL.html
+++ b/ACE/ACE-INSTALL.html
@@ -433,7 +433,7 @@ INSTALL_PREFIX = /usr/local
</li>
<li>If you need to regenerate the <code>ace/Svc_Conf_y.cpp</code> file,
you'll need to
- get <a href="http://ftp.gnu.org/pub/gnu/bison/">GNU Bison</a>.
+ get <a href="https://www.gnu.org/software/bison">GNU Bison</a>.
However, you should rarely, if ever, need to do this.
</li>
</ol>
@@ -451,8 +451,8 @@ one will not clean up any old files, and trying to use the environment's
"Clean" command will probably not account for all existing files.</p>
<p>For using MPC and our perl based test framework we recommend
-our windows users to use <a href="http://www.activestate.com/Products/ActivePerl/"> Active
-State Perl.</a></p>
+our windows users to use <a href="https://www.activestate.com/products/perl">Active
+State Perl</a> or <a href="http://strawberryperl.com">Strawberry Perl</a></p>
<ul>
<li><a href="#msvc">Microsoft Visual Studio</a></li>
@@ -1383,8 +1383,8 @@ A few additional Windows Notes, from Paul von Behren:<p>
<code>Tornado\host\x86-win32\bin\TorVars.bat</code>. This is done
implicitly within the Tornado IDE.<p>
</p></li><li>To run <code>ace_ld</code>, you still need perl installed -
- see <a href="http://www.activestate.com/software/default.htm">http://www.activestate.com/software/default.htm</a>
- for Windows perl.<p>
+ see <a href="https://www.activestate.com/products/perl">ActiveState Perl</a>
+ or <a href="http://strawberryperl.com">Strawberry Perl</a>.<p>
</p></li><li>The Tornado IDE will use a standard Makefile for project
builds, but does not have a GUI interface for managing the
Makefile. By default, it will use rules from Makefile in the current
@@ -1496,8 +1496,8 @@ host based card.</p>
</b><p>NT 4.0 workstation with 128 M RAM, 266MHz Pentium.</p>
<b><p>Software Needed For Building TAO</p>
-</b><p>1) Active State's ActivePerl from
-<a href="http://www.activestate.com/software/default.htm">http://www.activestate.com/software/default.htm</a>
+</b><p>1) <a href="https://www.activestate.com/products/perl">ActiveState Perl</a>
+or <a href="http://strawberryperl.com">Strawberry Perl</a>
</p>
<p>2) Tornado 2.2.1 from Windriver.</p>
@@ -3190,8 +3190,9 @@ quickly.
</p></li><li>Please make sure that you have <a href="http://www.perl.org/">
perl</a> installed, preferably perl
5.8 or higher. Users on Win32 based platforms are recommended to use
- <a href="http://www.activestate.com/Products/ActivePerl/"> Active
- State Perl</a>. We use active state perl without problems. We have
+ <a href="https://www.activestate.com/products/perl"> Active
+ State Perl</a> or <a href="http://strawberryperl.com">Strawberry Perl</a>.
+ We use both perl versions without problems. We have
ran into problems trying to use the cygwin version of perl on Win32
based platforms. <p>
</p></li>
diff --git a/ACE/COPYING b/ACE/COPYING
index fc3685c847a..5917f76aa79 100644
--- a/ACE/COPYING
+++ b/ACE/COPYING
@@ -86,26 +86,26 @@
References
- 1. http://www.dre.vanderbilt.edu/~schmidt/ACE.html
- 2. http://www.dre.vanderbilt.edu/~schmidt/TAO.html
- 3. http://www.dre.vanderbilt.edu/CIAO/
- 4. http://www.dre.vanderbilt.edu/cosmic/
- 5. http://www.dre.vanderbilt.edu/~schmidt/
- 6. http://www.dre.vanderbilt.edu/~schmidt/ACE-members.html
- 7. http://www.wustl.edu/
- 8. http://www.uci.edu/
- 9. http://www.vanderbilt.edu/
- 10. mailto:doc_group@cs.wustl.edu
- 11. http://www.dre.vanderbilt.edu/~schmidt/ACE-users.html
- 12. http://www.dre.vanderbilt.edu/~schmidt/ACE.html
- 13. http://www.dre.vanderbilt.edu/~schmidt/TAO.html
- 14. http://www.dre.vanderbilt.edu/CIAO/
- 15. http://www.dre.vanderbilt.edu/~schmidt/DOC_ROOT/DAnCE/
- 16. http://www.dre.vanderbilt.edu/cosmic/
- 17. http://www.dre.vanderbilt.edu/
- 18. http://www.isis.vanderbilt.edu/
- 19. http://www.cs.wustl.edu/~schmidt/doc-center.html
- 20. http://www.dre.vanderbilt.edu/~schmidt/commercial-support.html
+ 1. https://www.dre.vanderbilt.edu/~schmidt/ACE.html
+ 2. https://www.dre.vanderbilt.edu/~schmidt/TAO.html
+ 3. https://www.dre.vanderbilt.edu/CIAO/
+ 4. https://www.dre.vanderbilt.edu/cosmic/
+ 5. https://www.dre.vanderbilt.edu/~schmidt/
+ 6. https://www.dre.vanderbilt.edu/~schmidt/ACE-members.html
+ 7. https://www.wustl.edu/
+ 8. https://www.uci.edu/
+ 9. https://www.vanderbilt.edu/
+ 10. mailto:d.schmidt@vanderbilt.edu
+ 11. https://www.dre.vanderbilt.edu/~schmidt/ACE-users.html
+ 12. https://www.dre.vanderbilt.edu/~schmidt/ACE.html
+ 13. https://www.dre.vanderbilt.edu/~schmidt/TAO.html
+ 14. https://www.dre.vanderbilt.edu/CIAO/
+ 15. https://www.dre.vanderbilt.edu/~schmidt/DOC_ROOT/DAnCE/
+ 16. https://www.dre.vanderbilt.edu/cosmic/
+ 17. https://www.dre.vanderbilt.edu/
+ 18. https://www.isis.vanderbilt.edu/
+ 19. https://www.cs.wustl.edu/~schmidt/doc-center.html
+ 20. https://www.dre.vanderbilt.edu/~schmidt/commercial-support.html
21. mailto:d.schmidt@vanderbilt.edu
- 22. http://www.dre.vanderbilt.edu/~schmidt/
- 23. http://www.dre.vanderbilt.edu/~schmidt/ACE.html
+ 22. https://www.dre.vanderbilt.edu/~schmidt/
+ 23. https://www.dre.vanderbilt.edu/~schmidt/ACE.html
diff --git a/ACE/PROBLEM-REPORT-FORM b/ACE/PROBLEM-REPORT-FORM
index fdcf20763af..c97905e5e29 100644
--- a/ACE/PROBLEM-REPORT-FORM
+++ b/ACE/PROBLEM-REPORT-FORM
@@ -1,23 +1,23 @@
[Please use the PRF form below to submit bug reports, problem reports,
etc., to the ACE developers and interested users. Send it to
ace-bugs@list.isis.vanderbilt.edu, you must be subscribed to the list
- in order to be able to post to it. If you are using OCI, PrismTech, or
+ in order to be able to post to it. If you are using OCI, MicroFocus, or
Riverace's versions of ACE do not send bugs to this mailing list, but
instead contact those companies for support. Please also send your
PRF as plain ASCII text, _not_ uuencoded or as an attachment.
- We prefer that all bug reports be submitted through our bug tracking
- system. See $ACE_ROOT/docs/usage-bugzilla.html for more information
+ We prefer that all bug reports be submitted through github issues.
+ See https://github.com/DOCGroup/ACE_TAO/issues for more information
about how to do this. If you are unsure as to whether your problem
is a real bug or not then please submit your question to the mailing
list using the following form. Not using the problem report form
will make it harder or impossible to identify the problem, and in
many cases we will be unable to help at all. Also please try to
- browse bugzilla and the ChangeLog files to find out if your problem
- has been solved in a more recent version of ACE.
+ browse the existing github isssues and the ChangeLog files to find
+ out if your problem has been solved in a more recent version of ACE.
To subscribe to the list see
- http://www.dre.vanderbilt.edu/~schmidt/ACE-mail.html
+ https://www.dre.vanderbilt.edu/~schmidt/ACE-mail.html
Replace/remove all the explanatory text in brackets before mailing.
diff --git a/ACE/README b/ACE/README
index cf0a7af3e21..e00ba30f2e3 100644
--- a/ACE/README
+++ b/ACE/README
@@ -1,6 +1,6 @@
This document is also available at the following URL:
-http://www.dre.vanderbilt.edu/~schmidt/ACE.html
+https://www.dre.vanderbilt.edu/~schmidt/ACE.html
All software and documentation is available via both anonymous ftp and
http.
diff --git a/ACE/ace/Basic_Types.h b/ACE/ace/Basic_Types.h
index 31ba1d47c71..67916f8dc06 100644
--- a/ACE/ace/Basic_Types.h
+++ b/ACE/ace/Basic_Types.h
@@ -29,8 +29,8 @@
* - ACE_UINT16
* - ACE_INT32
* - ACE_UINT32
- * - ACE_UINT64
* - ACE_INT64
+ * - ACE_UINT64
*
* Byte-order (endian-ness) determination:
* ACE_BYTE_ORDER, to either ACE_BIG_ENDIAN or ACE_LITTLE_ENDIAN
diff --git a/ACE/ace/OS_NS_Thread.cpp b/ACE/ace/OS_NS_Thread.cpp
index db110aa5c29..4f1b8b08a69 100644
--- a/ACE/ace/OS_NS_Thread.cpp
+++ b/ACE/ace/OS_NS_Thread.cpp
@@ -4075,7 +4075,7 @@ ACE_OS::thr_create (ACE_THR_FUNC func,
else
# endif /* ACE_HAS_MFC */
{
- int start_suspended = ACE_BIT_ENABLED (flags, THR_SUSPENDED);
+ int const start_suspended = ACE_BIT_ENABLED (flags, THR_SUSPENDED);
if (priority != ACE_DEFAULT_THREAD_PRIORITY)
// If we need to set the priority, then we need to start the
@@ -4105,15 +4105,6 @@ ACE_OS::thr_create (ACE_THR_FUNC func,
}
}
}
-# if 0
- *thr_handle = ::CreateThread
- (0,
- stacksize,
- LPTHREAD_START_ROUTINE (thread_args->entry_point ()),
- thread_args,
- flags,
- thr_id);
-# endif /* 0 */
// Close down the handle if no one wants to use it.
if (thr_handle == &tmp_handle && tmp_handle != 0)
diff --git a/ACE/ace/Object_Manager.cpp b/ACE/ace/Object_Manager.cpp
index c98bec3e4bb..eb4dc69ef89 100644
--- a/ACE/ace/Object_Manager.cpp
+++ b/ACE/ace/Object_Manager.cpp
@@ -323,7 +323,6 @@ ACE_Object_Manager::init (void)
# endif // (_MSC_VER >= 1400) // VC++ 8.0 and above.
#endif /* ACE_DISABLE_WIN32_ERROR_WINDOWS */
-
# if !defined (ACE_LACKS_ACE_SVCCONF)
ACE_NEW_RETURN (preallocations_,
ACE_Object_Manager_Preallocations,
diff --git a/ACE/ace/Object_Manager.h b/ACE/ace/Object_Manager.h
index f3651742e16..33171fae85e 100644
--- a/ACE/ace/Object_Manager.h
+++ b/ACE/ace/Object_Manager.h
@@ -236,7 +236,7 @@ public:
/**
* Register an ACE_Cleanup object for cleanup at process
* termination. The object is deleted via the
- * <ace_cleanup_destroyer>. If you need more flexiblity, see the
+ * <ace_cleanup_destroyer>. If you need more flexibility, see the
* @c other at_exit method below. For OS's that do not have
* processes, cleanup takes place at the end of <main>. Returns 0
* on success. On failure, returns -1 and sets errno to: EAGAIN if
diff --git a/ACE/ace/Process_Manager.cpp b/ACE/ace/Process_Manager.cpp
index ee0418b8fca..4db0f020eed 100644
--- a/ACE/ace/Process_Manager.cpp
+++ b/ACE/ace/Process_Manager.cpp
@@ -26,6 +26,9 @@ ACE_Process_Manager_cleanup (void *instance, void *arg)
{
ACE_Process_Manager::cleanup (instance, arg);
}
+#define ACE_PROCESS_MANAGER_CLEANUP_FUNCTION ACE_Process_Manager_cleanup
+#else
+#define ACE_PROCESS_MANAGER_CLEANUP_FUNCTION ACE_Process_Manager::cleanup
#endif
ACE_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -124,19 +127,10 @@ ACE_Process_Manager::instance (void)
// Register with the Object_Manager so that the wrapper to
// delete the proactor will be called when Object_Manager is
// being terminated.
-
-#if defined ACE_HAS_SIG_C_FUNC
- ACE_Object_Manager::at_exit (ACE_Process_Manager::instance_,
- ACE_Process_Manager_cleanup,
- 0,
- typeid (*ACE_Process_Manager::instance_).name ());
-#else
ACE_Object_Manager::at_exit (ACE_Process_Manager::instance_,
- ACE_Process_Manager::cleanup,
+ ACE_PROCESS_MANAGER_CLEANUP_FUNCTION,
0,
- typeid (*ACE_Process_Manager::instance_).name ());
-#endif /* ACE_HAS_SIG_C_FUNC */
-
+ typeid (ACE_Process_Manager).name ());
}
}
@@ -157,18 +151,10 @@ ACE_Process_Manager::instance (ACE_Process_Manager *tm)
// Register with the Object_Manager so that the wrapper to
// delete the proactor will be called when Object_Manager is
// being terminated.
-
-#if defined ACE_HAS_SIG_C_FUNC
- ACE_Object_Manager::at_exit (ACE_Process_Manager::instance_,
- ACE_Process_Manager_cleanup,
- 0,
- typeid (*ACE_Process_Manager::instance_).name ());
-#else
ACE_Object_Manager::at_exit (ACE_Process_Manager::instance_,
- ACE_Process_Manager::cleanup,
- 0,
- typeid (*ACE_Process_Manager::instance_).name ());
-#endif /* ACE_HAS_SIG_C_FUNC */
+ ACE_PROCESS_MANAGER_CLEANUP_FUNCTION,
+ 0,
+ typeid (*t).name ());
ACE_Process_Manager::instance_ = tm;
return t;
diff --git a/ACE/ace/SSL/SSL_Asynch_Stream.cpp b/ACE/ace/SSL/SSL_Asynch_Stream.cpp
index b493e98a750..f084c5375e7 100644
--- a/ACE/ace/SSL/SSL_Asynch_Stream.cpp
+++ b/ACE/ace/SSL/SSL_Asynch_Stream.cpp
@@ -256,7 +256,6 @@ ACE_SSL_Asynch_Stream::open (ACE_Handler & handler,
ACE_TEXT ("- invalid handle")),
-1);
-
// Get a proactor for/from the user.
this->proactor_ = this->get_proactor (proactor, handler);
this->ext_handler_ = & handler;
@@ -407,8 +406,7 @@ ACE_SSL_Asynch_Stream::do_SSL_state_machine (void)
{
// this protected member should be called
// with locked mutex_
-
- int retval = this->do_SSL_handshake ();
+ int const retval = this->do_SSL_handshake ();
if (retval == 0) // handshake in progress ?
return 0;
@@ -527,7 +525,7 @@ ACE_SSL_Asynch_Stream::do_SSL_handshake (void)
-1);
}
- int status = ::SSL_get_error (this->ssl_, retval);
+ int const status = ::SSL_get_error (this->ssl_, retval);
switch (status)
{
@@ -552,7 +550,6 @@ ACE_SSL_Asynch_Stream::do_SSL_handshake (void)
return 1;
}
-
bool
ACE_SSL_Asynch_Stream::post_handshake_check (void)
{
diff --git a/ACE/ace/SSL/SSL_Asynch_Stream.h b/ACE/ace/SSL/SSL_Asynch_Stream.h
index de2a9dc169b..7a965995a76 100644
--- a/ACE/ace/SSL/SSL_Asynch_Stream.h
+++ b/ACE/ace/SSL/SSL_Asynch_Stream.h
@@ -373,7 +373,6 @@ private:
ACE_SSL_Asynch_Stream & operator= (ACE_SSL_Asynch_Stream const &);
protected:
-
/// Stream Type ST_CLIENT/ST_SERVER
Stream_Type type_;
@@ -447,7 +446,6 @@ protected:
/// Mutex to protect work
ACE_SYNCH_MUTEX mutex_;
-
};
ACE_END_VERSIONED_NAMESPACE_DECL
diff --git a/ACE/ace/SSL/SSL_Context.cpp b/ACE/ace/SSL/SSL_Context.cpp
index bbbfb632541..e0d6530f426 100644
--- a/ACE/ace/SSL/SSL_Context.cpp
+++ b/ACE/ace/SSL/SSL_Context.cpp
@@ -352,7 +352,6 @@ ACE_SSL_Context::filter_versions (const char* versionlist)
return 0;
}
-
bool
ACE_SSL_Context::check_host (const ACE_INET_Addr &host, SSL *peerssl)
{
@@ -360,7 +359,6 @@ ACE_SSL_Context::check_host (const ACE_INET_Addr &host, SSL *peerssl)
this->check_context ();
- int result = 0;
char name[MAXHOSTNAMELEN+1];
if (peerssl == 0 || host.get_host_name (name, MAXHOSTNAMELEN) == -1)
@@ -379,13 +377,13 @@ ACE_SSL_Context::check_host (const ACE_INET_Addr &host, SSL *peerssl)
int flags = X509_CHECK_FLAG_ALWAYS_CHECK_SUBJECT;
size_t len = ACE_OS::strlen (name);
- result = ::X509_check_host (cert, name, len, flags, peerarg);
+ int const result = ::X509_check_host (cert, name, len, flags, peerarg);
if (ACE::debug ())
{
ACELIB_DEBUG ((LM_DEBUG,
ACE_TEXT ("ACE (%P|%t) SSL_Context::check_host ")
- ACE_TEXT ("name <%s> returns %d, peer <%s>\n"),
+ ACE_TEXT ("name <%C> returns %d, peer <%s>\n"),
name, result, peer));
}
if (peer != 0)
@@ -516,7 +514,6 @@ ACE_SSL_Context::load_trusted_ca (const char* ca_file,
return 0;
}
-
int
ACE_SSL_Context::private_key (const char *file_name,
int type)
@@ -598,8 +595,7 @@ ACE_SSL_Context::set_verify_peer (int strict, int once, int depth)
{
this->check_context ();
- // Setup the peer verififcation mode.
-
+ // Setup the peer verification mode.
int verify_mode = SSL_VERIFY_PEER;
if (once)
verify_mode |= SSL_VERIFY_CLIENT_ONCE;
@@ -615,7 +611,6 @@ ACE_SSL_Context::set_verify_peer (int strict, int once, int depth)
::SSL_CTX_set_verify_depth (this->context_, depth + 1);
}
-
int
ACE_SSL_Context::random_seed (const char * seed)
{
diff --git a/ACE/ace/SSL/SSL_SOCK.h b/ACE/ace/SSL/SSL_SOCK.h
index 16e84af890f..29df1c85ce2 100644
--- a/ACE/ace/SSL/SSL_SOCK.h
+++ b/ACE/ace/SSL/SSL_SOCK.h
@@ -39,7 +39,6 @@ ACE_BEGIN_VERSIONED_NAMESPACE_DECL
class ACE_SSL_Export ACE_SSL_SOCK : public ACE_SOCK
{
public:
-
/**
* Override ACE_SOCK base class implementations with these SSL
* specific ones.
@@ -61,7 +60,6 @@ public:
//@}
protected:
-
/// Default constructor is private to prevent instances of this class
/// from being defined.
ACE_SSL_SOCK (void);
@@ -73,7 +71,6 @@ protected:
* ACE_SSL_SOCK pointer/reference.
*/
~ACE_SSL_SOCK (void);
-
};
ACE_END_VERSIONED_NAMESPACE_DECL
diff --git a/ACE/ace/SSL/SSL_SOCK_Acceptor.cpp b/ACE/ace/SSL/SSL_SOCK_Acceptor.cpp
index d790662af29..9ec3d58e9a2 100644
--- a/ACE/ace/SSL/SSL_SOCK_Acceptor.cpp
+++ b/ACE/ace/SSL/SSL_SOCK_Acceptor.cpp
@@ -23,7 +23,6 @@ ACE_SSL_SOCK_Acceptor::~ACE_SSL_SOCK_Acceptor (void)
ACE_TRACE ("ACE_SSL_SOCK_Acceptor::~ACE_SSL_SOCK_Acceptor");
}
-
int
ACE_SSL_SOCK_Acceptor::ssl_accept (ACE_SSL_SOCK_Stream &new_stream,
ACE_Time_Value *timeout) const
diff --git a/ACE/ace/SSL/SSL_SOCK_Acceptor.h b/ACE/ace/SSL/SSL_SOCK_Acceptor.h
index 83f56510005..e71226be9fe 100644
--- a/ACE/ace/SSL/SSL_SOCK_Acceptor.h
+++ b/ACE/ace/SSL/SSL_SOCK_Acceptor.h
@@ -49,7 +49,6 @@ ACE_BEGIN_VERSIONED_NAMESPACE_DECL
class ACE_SSL_Export ACE_SSL_SOCK_Acceptor : public ACE_SSL_SOCK
{
public:
-
/// Default constructor.
ACE_SSL_SOCK_Acceptor (void);
@@ -175,16 +174,13 @@ public:
ACE_ALLOC_HOOK_DECLARE;
protected:
-
/// Complete SSL passive connection establishment.
int ssl_accept (ACE_SSL_SOCK_Stream &new_stream,
ACE_Time_Value *timeout) const;
private:
-
/// The BSD-socket workhorse
ACE_SOCK_Acceptor acceptor_;
-
};
ACE_END_VERSIONED_NAMESPACE_DECL
diff --git a/ACE/ace/SSL/SSL_SOCK_Connector.h b/ACE/ace/SSL/SSL_SOCK_Connector.h
index 4c862c9fbac..72917a0abb0 100644
--- a/ACE/ace/SSL/SSL_SOCK_Connector.h
+++ b/ACE/ace/SSL/SSL_SOCK_Connector.h
@@ -53,9 +53,7 @@ ACE_BEGIN_VERSIONED_NAMESPACE_DECL
*/
class ACE_SSL_Export ACE_SSL_SOCK_Connector
{
-
public:
-
/// Default constructor.
ACE_SSL_SOCK_Connector (void);
@@ -292,17 +290,14 @@ public:
ACE_ALLOC_HOOK_DECLARE;
protected:
-
/// Complete non-blocking SSL active connection.
int ssl_connect (ACE_SSL_SOCK_Stream &new_stream,
const ACE_Time_Value *timeout);
private:
-
/// The class that does all of the non-secure socket connection.
- /// It is default contructed, and subsequently used by connect().
+ /// It is default constructed, and subsequently used by connect().
ACE_SOCK_Connector connector_;
-
};
ACE_END_VERSIONED_NAMESPACE_DECL
diff --git a/ACE/ace/SSL/SSL_SOCK_Stream.cpp b/ACE/ace/SSL/SSL_SOCK_Stream.cpp
index b8f6ba00cb8..113adf25a61 100644
--- a/ACE/ace/SSL/SSL_SOCK_Stream.cpp
+++ b/ACE/ace/SSL/SSL_SOCK_Stream.cpp
@@ -563,7 +563,6 @@ ACE_SSL_SOCK_Stream::get_remote_addr (ACE_Addr &addr) const
// complete. Despite that fact, the SSL connection may not have
// been completed. In such a case, a successful return from
// get_remote_addr() would be misleading.
-
if (SSL_is_init_finished (this->ssl_))
{
return this->ACE_SSL_SOCK::get_remote_addr (addr);
diff --git a/ACE/ace/SSL/SSL_SOCK_Stream.h b/ACE/ace/SSL/SSL_SOCK_Stream.h
index c9a54fe98af..ed75a132747 100644
--- a/ACE/ace/SSL/SSL_SOCK_Stream.h
+++ b/ACE/ace/SSL/SSL_SOCK_Stream.h
@@ -60,7 +60,6 @@ ACE_BEGIN_VERSIONED_NAMESPACE_DECL
class ACE_SSL_Export ACE_SSL_SOCK_Stream : public ACE_SSL_SOCK
{
public:
-
/// Constructor
/**
* @param context Pointer to @c ACE_SSL_Context instance containing
@@ -75,7 +74,7 @@ public:
/// Destructor
~ACE_SSL_SOCK_Stream (void);
- /// Send an n byte buffer to the ssl socket using the semantics of
+ /// Send an @a n byte buffer to the ssl socket using the semantics of
/// send(3n).
/**
* ACE_SSL supports no flags for sending at this time.
@@ -84,7 +83,7 @@ public:
size_t n,
int flags) const;
- /// Recv an n byte buffer from the ssl socket using the semantics of
+ /// Recv an @a n byte buffer from the ssl socket using the semantics of
/// recv(3n).
/**
* ACE_SSL supports MSG_PEEK, but no other flags at this time.
@@ -93,17 +92,17 @@ public:
size_t n,
int flags) const;
- /// Send an n byte buffer to the ssl socket using the semantics of
+ /// Send an @a n byte buffer to the ssl socket using the semantics of
/// write(2).
ssize_t send (const void *buf,
size_t n) const;
- /// Recv an n byte buffer from the ssl socket using the semantics of
+ /// Recv an @a n byte buffer from the ssl socket using the semantics of
/// read(2).
ssize_t recv (void *buf,
size_t n) const;
- /// Send an iovec of size n to the ssl socket.
+ /// Send an iovec of size @a n to the ssl socket.
/**
* Note that it is not possible to perform a "scattered" write with
* the underlying OpenSSL implementation. As such, the expected
@@ -136,8 +135,8 @@ public:
const ACE_Time_Value *timeout) const;
/**
- * Wait up to timeout amount of time to receive up to n bytes into
- * buf (uses the recv() call). If recv() times out -1 is returned
+ * Wait up to timeout amount of time to receive up to @a n bytes into
+ * @a buf (uses the recv() call). If recv() times out -1 is returned
* with errno == ETIME. If it succeeds the number of bytes received
* is returned. MSG_PEEK is the only supported flag.
*/
@@ -147,8 +146,8 @@ public:
const ACE_Time_Value *timeout) const;
/**
- * Wait to to timeout amount of time to send up to n bytes into
- * buf (uses the send() call). If send() times out
+ * Wait to to timeout amount of time to send up to @a n bytes into
+ * @a buf (uses the send() call). If send() times out
* a -1 is returned with errno == ETIME. If it succeeds the
* number of bytes sent is returned.
*/
@@ -157,8 +156,8 @@ public:
const ACE_Time_Value *timeout) const;
/**
- * Wait up to timeout amount of time to receive up to n bytes
- * into buf (uses the recv() call). If recv() times
+ * Wait up to timeout amount of time to receive up to @a n bytes
+ * into @a buf (uses the recv() call). If recv() times
* out a -1 is returned with @c errno == ETIME. If it succeeds the
* number of bytes received is returned.
*/
@@ -166,18 +165,18 @@ public:
size_t n,
const ACE_Time_Value *timeout) const;
- /// Send n varargs messages to the connected ssl socket.
+ /// Send @a n varargs messages to the connected ssl socket.
ssize_t send (size_t n,
...) const;
- /// Recv n varargs messages to the connected ssl socket.
+ /// Recv @a n varargs messages to the connected ssl socket.
ssize_t recv (size_t n,
...) const;
- /// Send n bytes, keep trying until n are sent.
+ /// Send @a n bytes, keep trying until n are sent.
ssize_t send_n (const void *buf, int n) const;
- /// Recv n bytes, keep trying until n are received.
+ /// Recv @a n bytes, keep trying until @a n are received.
ssize_t recv_n (void *buf, int n) const;
/**
@@ -185,14 +184,14 @@ public:
* for recv_n(), and no flags are supported for send_n().
*/
//@{
- /// Send n bytes, keep trying until n are sent.
+ /// Send @a n bytes, keep trying until @a n are sent.
ssize_t send_n (const void *buf, int n, int flags) const;
- /// Recv n bytes, keep trying until n are sent.
+ /// Recv @a n bytes, keep trying until @a n are sent.
ssize_t recv_n (void *buf, int n, int flags) const;
/**
- * Try to send exactly len bytes into buf (uses the send() call).
+ * Try to send exactly @a len bytes into @a buf (uses the send() call).
* If send() blocks for longer than timeout the number of bytes
* actually sent is returned with errno == ETIME. If a timeout does
* not occur, send_n() return len (i.e., the number of bytes
@@ -205,7 +204,7 @@ public:
size_t *bytes_transferred = 0) const;
/**
- * Try to send exactly len bytes into buf (uses the send() call).
+ * Try to send exactly @a len bytes into @a buf (uses the send() call).
* If send() blocks for longer than timeout the number of bytes
* actually sent is returned with errno == ETIME. If a timeout does
* not occur, send_n() return len (i.e., the number of bytes
@@ -217,7 +216,7 @@ public:
size_t *bytes_transferred = 0) const;
/**
- * Try to receive exactly len bytes into buf (uses the recv() call).
+ * Try to receive exactly @a len bytes into @a buf (uses the recv() call).
* The ACE_Time_Value indicates how long to blocking trying to
* receive. If timeout == 0, the caller will block until action is
* possible, else will wait until the relative time specified in
@@ -259,7 +258,6 @@ public:
ssize_t recvv_n (iovec iov[],
size_t n) const;
-
/**
* Selectively close endpoints.
*/
@@ -293,7 +291,7 @@ public:
/**
* Return the address of the remotely connected peer (if there is
- * one), in the referenced <ACE_Addr>. Returns 0 if successful, else
+ * one), in the referenced ACE_Addr. Returns 0 if successful, else
* -1.
*
* @note If the TCP connection has been completed but the SSL
@@ -306,7 +304,6 @@ public:
ACE_SOCK_Stream & peer (void);
protected:
-
/// Underlying send() helper method common to all public send()
/// methods.
ssize_t send_i (const void *buf,
@@ -321,18 +318,15 @@ protected:
const ACE_Time_Value *timeout) const;
private:
-
ACE_UNIMPLEMENTED_FUNC (void operator= (const ACE_SSL_SOCK_Stream &))
ACE_UNIMPLEMENTED_FUNC (ACE_SSL_SOCK_Stream (const ACE_SSL_SOCK_Stream &))
protected:
-
/// The SSL session.
SSL *ssl_;
/// The stream which works under the ssl connection.
ACE_SOCK_Stream stream_;
-
};
ACE_END_VERSIONED_NAMESPACE_DECL
diff --git a/ACE/ace/SSL/SSL_SOCK_Stream.inl b/ACE/ace/SSL/SSL_SOCK_Stream.inl
index c2a5bf2c8ba..7e9420bfb73 100644
--- a/ACE/ace/SSL/SSL_SOCK_Stream.inl
+++ b/ACE/ace/SSL/SSL_SOCK_Stream.inl
@@ -101,7 +101,6 @@ ACE_SSL_SOCK_Stream::recv_i (void *buf,
ACE_TRACE ("ACE_SSL_SOCK_Stream::recv_i");
// NOTE: Caller must provide thread-synchronization.
-
int bytes_read = 0;
ACE_HANDLE const handle = this->get_handle ();
diff --git a/ACE/ace/config-android.h b/ACE/ace/config-android.h
index c30389f1f64..d3d89f39d5b 100644
--- a/ACE/ace/config-android.h
+++ b/ACE/ace/config-android.h
@@ -123,6 +123,14 @@
# endif
#endif
+#if ACE_ANDROID_NDK_LESS_THAN(15, 0)
+# define ACE_LACKS_STRUCT_IF_NAMEINDEX
+#endif
+
+#if ACE_ANDROID_NDK_LESS_THAN(15, 0) || __ANDROID_API__ < 24
+# define ACE_LACKS_IF_NAMEINDEX
+#endif
+
// These were available before r18, but in r18 they are restricted to API >= 28 ¯\_(ツ)_/¯
#if __ANDROID_API__ < 28
# define ACE_LACKS_SETHOSTENT
diff --git a/ACE/ace/config-win32-common.h b/ACE/ace/config-win32-common.h
index 624cce15114..31b3bffd3f9 100644
--- a/ACE/ace/config-win32-common.h
+++ b/ACE/ace/config-win32-common.h
@@ -569,6 +569,7 @@
# define ACE_LACKS_IF_NAMETOINDEX
#endif
#define ACE_LACKS_IF_NAMEINDEX
+#define ACE_LACKS_STRUCT_IF_NAMEINDEX
// Platform supports IP multicast on Winsock 2
#if defined (ACE_HAS_WINSOCK2) && (ACE_HAS_WINSOCK2 != 0)
diff --git a/ACE/ace/os_include/net/os_if.h b/ACE/ace/os_include/net/os_if.h
index ed85fa93d4d..f02af7b5ef8 100644
--- a/ACE/ace/os_include/net/os_if.h
+++ b/ACE/ace/os_include/net/os_if.h
@@ -102,7 +102,7 @@ struct ifconf {
# define IFF_BROADCAST 0x2
#endif /* IFF_BROADCAST */
-#if defined ACE_HAS_WINSOCK2 && defined ACE_LACKS_IF_NAMEINDEX
+#if defined (ACE_LACKS_STRUCT_IF_NAMEINDEX)
struct if_nameindex {};
#endif
diff --git a/ACE/bin/ace-install b/ACE/bin/ace-install
index 8bf684a35e0..123a3e3afeb 100755
--- a/ACE/bin/ace-install
+++ b/ACE/bin/ace-install
@@ -29,6 +29,8 @@ force=0
# can we do it?
die=0
+# this script name without path
+this_script=$(basename $0)
#####################################################################
# check for install_ace options
@@ -43,7 +45,7 @@ while [ $# -gt 0 ]; do
-h | --help*)
echo " "
- echo "`basename $0` [options]"
+ echo "$this_script [options]"
echo " "
echo "options:"
echo " -h, --help show brief help"
@@ -83,7 +85,7 @@ while [ $# -gt 0 ]; do
;;
--aceroot*)
- ACE_ROOT=`echo $1 | sed -e 's/^[^=]*=//g'`; export ACE_ROOT
+ ACE_ROOT=$(echo $1 | sed -e 's/^[^=]*=//g'); export ACE_ROOT
shift
;;
@@ -103,7 +105,7 @@ while [ $# -gt 0 ]; do
;;
--archive*)
- ACE_ARCHIVE=`echo $1 | sed -e 's/^[^=]*=//g'`; export ACE_ARCHIVE
+ ACE_ARCHIVE=$(echo $1 | sed -e 's/^[^=]*=//g'); export ACE_ARCHIVE
unpack=1
shift
;;
@@ -111,8 +113,8 @@ while [ $# -gt 0 ]; do
-p)
shift
if [ $# -gt 0 ]; then
- ACE_HEADER=`echo $1 | cut -f 1 -d ,`; export ACE_HEADER
- ACE_MAKE=`echo $1 | cut -f 2 -d ,`; export ACE_MAKE
+ ACE_HEADER=$(echo $1 | cut -f 1 -d ,); export ACE_HEADER
+ ACE_MAKE=$(echo $1 | cut -f 2 -d ,); export ACE_MAKE
else
echo "no header,make files specified"
exit 1
@@ -122,9 +124,9 @@ while [ $# -gt 0 ]; do
;;
--platform*)
- stuff=`echo $1 | sed -e 's/^[^=]*=//g'`
- ACE_HEADER=`echo $stuff | cut -f 1 -d ,`; export ACE_HEADER
- ACE_MAKE=`echo $stuff | cut -f 2 -d ,`; export ACE_MAKE
+ stuff=$(echo $1 | sed -e 's/^[^=]*=//g')
+ ACE_HEADER=$(echo $stuff | cut -f 1 -d ,); export ACE_HEADER
+ ACE_MAKE=$(echo $stuff | cut -f 2 -d ,); export ACE_MAKE
config=1
shift
;;
@@ -145,7 +147,7 @@ while [ $# -gt 0 ]; do
;;
--compile*)
- ACE_OPTS=`echo $1 | sed -e 's/^[^=]*=//g'`; export ACE_OPTS
+ ACE_OPTS=$(echo $1 | sed -e 's/^[^=]*=//g'); export ACE_OPTS
compile=1
shift
;;
@@ -166,7 +168,7 @@ while [ $# -gt 0 ]; do
;;
--install*)
- ACE_DEST=`echo $1 | sed -e 's/^[^=]*=//g'`; export ACE_DEST
+ ACE_DEST=$(echo $1 | sed -e 's/^[^=]*=//g'); export ACE_DEST
install=1
shift
;;
@@ -183,7 +185,7 @@ while [ $# -gt 0 ]; do
;;
--arch*)
- ACE_ARCH=`echo $1 | sed -e 's/^[^=]*=//g'`; export ACE_ARCH
+ ACE_ARCH=$(echo $1 | sed -e 's/^[^=]*=//g'); export ACE_ARCH
shift
;;
@@ -210,32 +212,32 @@ done
# sanity checks for required variables
#####################################################################
-if [ $install -ne 0 -a $compile -ne 0 -a $unpack -eq 0 ]; then
+if [ $install -ne 0 ] && [ $compile -ne 0 ] && [ $unpack -eq 0 ]; then
echo "- No actions specified."
die=1
fi
-if [ $unpack -ne 0 -a $compile -ne 0 -a $config -eq 0 ] \
- || [ $unpack -ne 0 -a $install -ne 0 -a $config -eq 0 ]; then
+if [ $unpack -ne 0 ] && [ $compile -ne 0 ] && [ $config -eq 0 ] \
+ || [ $unpack -ne 0 ] && [ $install -ne 0 ] && [ $config -eq 0 ]; then
echo "- Must set platform config options with --platform option"
- echo " (`basename $0` -h for help) to unpack and compile/install"
+ echo " ($this_script -h for help) to unpack and compile/install"
die=1
fi
if [ -z "$ACE_ROOT" ]; then
echo "- Must set ACE_ROOT directory before proceeding..."
echo " The directory may be set with the ACE_ROOT environment"
- echo " variable or the --aceroot option (`basename $0` -h for help)"
+ echo " variable or the --aceroot option ($this_script -h for help)"
die=1
fi
-if [ $install -eq 1 -a -z "$ACE_ARCH" ]; then
+if [ $install -eq 1 ] && [ -z "$ACE_ARCH" ]; then
# just set it to blank if we want to flatten this level of subdirectory
ACE_ARCH=""
fi
if [ $die -ne 0 ]; then
- echo "- terminating `basename $0` script"
+ echo "- terminating $this_script script"
exit 2
fi
@@ -285,7 +287,7 @@ if [ $force -eq 0 ]; then
echo " "
echo "Type 'yes' to proceed, anything else to exit"
- read ready
+ read -r ready
if [ "$ready" != "yes" ]; then
echo "Terminating install script. Thank you for playing."
echo "We have some lovely parting gifts for you. =)"
@@ -302,7 +304,7 @@ if [ $unpack -ne 0 ]; then
echo "Unpacking $ACE_ARCHIVE..."
- cd `dirname $ACE_ROOT`
+ cd $(dirname $ACE_ROOT)
gzip -dc $ACE_ARCHIVE | tar xvf -
fi
@@ -350,7 +352,7 @@ if [ $compile -ne 0 ]; then
##########################################
# add ACE_ROOT/ace to LD_LIBRARY_PATH so tao_idl can find libACE.so
- if [ "`uname -s`" = "HP-UX" ]; then
+ if [ "$(uname -s)" = "HP-UX" ]; then
if [ ! -z "$SHLIB_PATH" ]; then
SHLIB_PATH=$ACE_ROOT/ace:$SHLIB_PATH
else
@@ -389,10 +391,10 @@ if [ $install -ne 0 ]; then
##########################################
# determine final target directories
- ACE_VER=`head -n 1 $ACE_ROOT/VERSION.txt | sed -e 's/^[^0-9]*//' -e 's/[, ].*//'`
+ ACE_VER=$(head -n 1 $ACE_ROOT/VERSION.txt | sed -e 's/^[^0-9]*//' -e 's/[, ].*//')
ACE_DIR="$ACE_DEST/ACE-$ACE_VER"; export ACE_DIR
- TAO_VER=`head -n 1 $ACE_ROOT/TAO/VERSION.txt | sed -e 's/^[^0-9]*//' -e 's/[, ].*//'`
+ TAO_VER=$(head -n 1 $ACE_ROOT/TAO/VERSION.txt | sed -e 's/^[^0-9]*//' -e 's/[, ].*//')
TAO_DIR="$ACE_DEST/TAO-$TAO_VER"; export ACE_DIR
##########################################
@@ -438,7 +440,7 @@ if [ $install -ne 0 ]; then
# copy TAO libs
echo "Copying libraries..."
- for f in `find . -type f -name "lib?*" -not -name "*\.dsw" -not -name "*Test*" -print`; do
+ for f in $(find . -type f \( -name "lib?*.so*" -o -name "lib?*.a" -o -name "lib?*.dll" -o -name "*.dylib" \) -print); do
echo $f
cp $f $TAO_DIR/$ACE_ARCH/lib
done
@@ -446,9 +448,9 @@ if [ $install -ne 0 ]; then
# copy TAO executables
echo "Copying executables..."
- ALL_PROGS=`find orbsvcs -type f -perm /a+x -print | grep -v ".*lib.*" | grep -v ".\.pl" | grep -v test | grep -v example`
- ALL_PROGS="`find utils -type f -perm /a+x -print` $ALL_PROGS"
- PROGS=`echo $ALL_PROGS | tr " " "\n" | grep -v test | grep -v default.bld | grep -v README | grep -v GNUmakefile`
+ ALL_PROGS=$(find orbsvcs -type f -perm /a+x -print | grep -v ".*lib.*" | grep -v ".\.pl" | grep -v test | grep -v example)
+ ALL_PROGS="$(find utils -type f -perm /a+x -print) $ALL_PROGS"
+ PROGS=$(echo $ALL_PROGS | tr " " "\n" | grep -v test | grep -v default.bld | grep -v README | grep -v GNUmakefile)
for f in TAO_IDL/tao_idl $PROGS; do
echo $f
@@ -471,9 +473,9 @@ if [ $install -ne 0 ]; then
# copy ACE libs
echo "Copying libraries..."
- for f in `find . -type f -name "lib?*" -not -name "*\.dsw" -not -name "*Test*" -print`; do
+ for f in $(find . -type f \( -name "lib?*.so*" -o -name "lib?*.a" -o -name "lib?*.dll" -o -name "*.dylib" \) -print); do
# only copy libs if they're not already in $TAO_DIR/$ACE_ARCH/lib
- maybe_tao_lib=$TAO_DIR/$ACE_ARCH/lib/`basename $f`
+ maybe_tao_lib=$TAO_DIR/$ACE_ARCH/lib/$(basename $f)
if [ ! -f $maybe_tao_lib ]; then
echo $f
cp $f $ACE_DIR/$ACE_ARCH/lib
@@ -483,7 +485,7 @@ if [ $install -ne 0 ]; then
# copy ACE executables
echo "Copying executables..."
- ACE_PROGS=apps/gperf/src/gperf
+ ACE_PROGS=apps/gperf/src/ace_gperf
for f in $ACE_PROGS; do
echo $f
@@ -507,4 +509,4 @@ fi # if [ $install -ne 0 ]
# that's all, folks
#####################################################################
-echo "`basename $0`: done."
+echo "$this_script: done."
diff --git a/ACE/examples/IPC_SAP/SSL_SAP/README b/ACE/examples/IPC_SAP/SSL_SAP/README
index 6e7f0b51e27..f47c084da13 100644
--- a/ACE/examples/IPC_SAP/SSL_SAP/README
+++ b/ACE/examples/IPC_SAP/SSL_SAP/README
@@ -1,5 +1,3 @@
-
-
This directory contains groups of client and server test programs that
exercise the various C++ wrappers for SSL sockets. In general, the
test programs do more or less the same thing -- the client establishes
diff --git a/ACE/examples/IPC_SAP/SSL_SAP/SSL-client-simple.h b/ACE/examples/IPC_SAP/SSL_SAP/SSL-client-simple.h
index 66e030b51bc..db1ad45bf4c 100644
--- a/ACE/examples/IPC_SAP/SSL_SAP/SSL-client-simple.h
+++ b/ACE/examples/IPC_SAP/SSL_SAP/SSL-client-simple.h
@@ -73,7 +73,7 @@ private:
// Sleep_Time value.
enum {QUIT_STRING_SIZE = 128};
- char quit_string_[QUIT_STRING_SIZE];
+ char quit_string_[QUIT_STRING_SIZE + 1];
// String that shuts down the client/server.
size_t message_len_;
diff --git a/ACE/examples/IPC_SAP/SSL_SAP/SSL-client.h b/ACE/examples/IPC_SAP/SSL_SAP/SSL-client.h
index 073ca0f9cac..e445e35c147 100644
--- a/ACE/examples/IPC_SAP/SSL_SAP/SSL-client.h
+++ b/ACE/examples/IPC_SAP/SSL_SAP/SSL-client.h
@@ -10,80 +10,79 @@
#include "ace/SSL/SSL_SOCK_Stream.h"
+/// Define the options for this test.
class Options
- // = TITLE
- // Define the options for this test.
{
public:
- Options (void);
// Constructor.
+ Options (void);
- ~Options (void);
// Destructor.
+ ~Options (void);
- int parse_args (int argc, ACE_TCHAR *argv[]);
// Parse the command-line arguments.
+ int parse_args (int argc, ACE_TCHAR *argv[]);
- const ACE_Time_Value &sleep_time (void) const;
// Return the amount of time to sleep in order to implement the
// proper transmission rates.
+ const ACE_Time_Value &sleep_time (void) const;
- u_short port (void) const;
// Port of the server.
+ u_short port (void) const;
- const ACE_TCHAR *host (void) const;
// Host of the server.
+ const ACE_TCHAR *host (void) const;
- size_t threads (void) const;
// Number of threads.
+ size_t threads (void) const;
- const char *quit_string (void) const;
// String that shuts down the client/server.
+ const char *quit_string (void) const;
- ssize_t read (void *buf, size_t len, size_t &iterations);
// Read from the appropriate location.
+ ssize_t read (void *buf, size_t len, size_t &iterations);
- size_t message_len (void) const;
// Returns the length of the message to send.
+ size_t message_len (void) const;
- const void *message_buf (void) const;
// Returns a pointer to the message.
+ const void *message_buf (void) const;
- ACE_THR_FUNC thr_func (void);
// Returns a pointer to the entry point into the thread that runs
// the client test function.
+ ACE_THR_FUNC thr_func (void);
private:
- int init (void);
// Initialize the message we're sending to the user and set up the
// barrier.
+ int init (void);
- char *shared_client_test (u_short port,
- ACE_SSL_SOCK_Stream &cli_stream);
// Performs the shared behavior of the oneway and twoway client
// tests.
+ char *shared_client_test (u_short port,
+ ACE_SSL_SOCK_Stream &cli_stream);
- static void *twoway_client_test (void *);
// Performs the twoway test.
+ static void *twoway_client_test (void *);
- static void *oneway_client_test (void *);
// Performs the oneway test.
+ static void *oneway_client_test (void *);
- const ACE_TCHAR *host_;
// Host of the server.
+ const ACE_TCHAR *host_;
- u_short port_;
// Port of the server.
+ u_short port_;
- ACE_Time_Value sleep_time_;
// Sleep_Time value.
+ ACE_Time_Value sleep_time_;
- size_t threads_;
// Number of threads.
+ size_t threads_;
- enum {QUIT_STRING_SIZE = 128};
- char quit_string_[QUIT_STRING_SIZE];
// String that shuts down the client/server.
+ enum {QUIT_STRING_SIZE = 128};
+ char quit_string_[QUIT_STRING_SIZE + 1];
size_t message_len_;
// Size of the message we send to the server.
diff --git a/ACE/examples/IPC_SAP/SSL_SAP/SSL-server-simple.cpp b/ACE/examples/IPC_SAP/SSL_SAP/SSL-server-simple.cpp
index 07f599db404..b6cae2fe044 100644
--- a/ACE/examples/IPC_SAP/SSL_SAP/SSL-server-simple.cpp
+++ b/ACE/examples/IPC_SAP/SSL_SAP/SSL-server-simple.cpp
@@ -5,13 +5,10 @@
#include "ace/Handle_Set.h"
#include "ace/Profile_Timer.h"
#include "ace/OS_NS_sys_select.h"
-
#include "ace/SSL/SSL_SOCK_Acceptor.h"
-
-
// Are we running verbosely?
-static int verbose = 1;
+static bool verbose = true;
// Function entry point into the twoway server task.
diff --git a/ACE/examples/IPC_SAP/SSL_SAP/SSL-server.cpp b/ACE/examples/IPC_SAP/SSL_SAP/SSL-server.cpp
index 2b23d67d8bc..012ac569d99 100644
--- a/ACE/examples/IPC_SAP/SSL_SAP/SSL-server.cpp
+++ b/ACE/examples/IPC_SAP/SSL_SAP/SSL-server.cpp
@@ -10,10 +10,8 @@
#include "ace/SSL/SSL_SOCK_Acceptor.h"
-
-
// Are we running verbosely?
-static int verbose = 0;
+static bool verbose = false;
static void
run_server (ACE_THR_FUNC server,
@@ -34,7 +32,6 @@ run_server (ACE_THR_FUNC server,
}
// Function entry point into the twoway server task.
-
static ACE_THR_FUNC_RETURN
twoway_server (void *arg)
{
diff --git a/ACE/tests/Network_Adapters_Test.cpp b/ACE/tests/Network_Adapters_Test.cpp
index 0e43095c5bb..395b49cf117 100644
--- a/ACE/tests/Network_Adapters_Test.cpp
+++ b/ACE/tests/Network_Adapters_Test.cpp
@@ -844,7 +844,7 @@ extern "C"
#endif /* #if defined (ACE_HAS_SIG_C_FUNC) */
#if defined (ACE_WIN32) && !defined (ACE_HAS_WINCE)
-BOOL CtrlHandler(DWORD fdwCtrlType)
+static BOOL WINAPI CtrlHandler(DWORD fdwCtrlType)
{
switch (fdwCtrlType)
{
@@ -1021,7 +1021,7 @@ run_main (int argc, ACE_TCHAR *argv[])
#if defined (ACE_WIN32)
#if !defined (ACE_HAS_WINCE)
- SetConsoleCtrlHandler((PHANDLER_ROUTINE) CtrlHandler, TRUE);
+ SetConsoleCtrlHandler(&CtrlHandler, TRUE);
#endif
#else /* #if defined (ACE_WIN32) */
// Set a handler for SIGSEGV signal to call for abort.
diff --git a/ACE/tests/Process_Env_Test.cpp b/ACE/tests/Process_Env_Test.cpp
index e6f8bdc5099..8334dbd15a3 100644
--- a/ACE/tests/Process_Env_Test.cpp
+++ b/ACE/tests/Process_Env_Test.cpp
@@ -35,14 +35,12 @@ void create_large_env (setenvfn_t setenv, void *ctx)
}
}
-
void apo_setenv (const ACE_TCHAR *name, const ACE_TCHAR *value, void *ctx)
{
ACE_Process_Options *apo = static_cast<ACE_Process_Options *> (ctx);
apo->setenv (name, value);
}
-
void thisproc_setenv (const ACE_TCHAR *name, const ACE_TCHAR *value, void *)
{
ACE_TString putstr (name);
@@ -50,7 +48,6 @@ void thisproc_setenv (const ACE_TCHAR *name, const ACE_TCHAR *value, void *)
putstr += value;
ACE_OS::putenv (putstr.c_str ());
}
-
#endif
int
@@ -71,10 +68,23 @@ run_main (int, ACE_TCHAR*[])
ACE_Process process;
if (process.spawn (options) != -1)
{
- ACE_ERROR ((LM_ERROR,
- "ERROR: This should have failed due to the large "
- "environment buffer\n"));
- test_status = 1;
+ /*
+ * In Windows versions < Vista the ENTIRE environment block could be a
+ * maximum of 32,767 bytes long
+ *
+ * In Windows versions > Vista it's 32,767 bytes per environment variable
+ */
+#if (_WIN32_WINNT < 0x0600)
+ ACE_ERROR ((LM_ERROR,
+ "ERROR: This should have failed due to the large "
+ "environment buffer\n"));
+
+ test_status = 1;
+#else
+ ACE_DEBUG ((LM_DEBUG,
+ "Using large environment buffer works as expected "
+ "on Windows vista or newer\n"));
+#endif /* _WIN32_WINNT < 0x0600 */
}
options.enable_unicode_environment ();
diff --git a/ACE/tests/SSL/Bug_2912_Regression_Test.cpp b/ACE/tests/SSL/Bug_2912_Regression_Test.cpp
index c713456137a..653b9ade93d 100644
--- a/ACE/tests/SSL/Bug_2912_Regression_Test.cpp
+++ b/ACE/tests/SSL/Bug_2912_Regression_Test.cpp
@@ -114,7 +114,6 @@ Client_Proactor_Task::svc (void)
return 0;
}
-
/**
* Server's proactor
*/
diff --git a/ACE/tests/SSL/Thread_Pool_Reactor_SSL_Test.cpp b/ACE/tests/SSL/Thread_Pool_Reactor_SSL_Test.cpp
index 8008e7351ab..548c18f1e89 100644
--- a/ACE/tests/SSL/Thread_Pool_Reactor_SSL_Test.cpp
+++ b/ACE/tests/SSL/Thread_Pool_Reactor_SSL_Test.cpp
@@ -32,7 +32,6 @@
*/
//=============================================================================
-
#include "../test_config.h"
#include "ace/OS_NS_string.h"
#include "ace/OS_NS_unistd.h"
@@ -43,8 +42,6 @@
#include "ace/SSL/SSL_SOCK_Connector.h"
#include "ace/SSL/SSL_SOCK_Acceptor.h"
-
-
#if defined (ACE_HAS_THREADS)
#include "Thread_Pool_Reactor_SSL_Test.h"
@@ -104,7 +101,7 @@ parse_arg (int argc, ACE_TCHAR *argv[])
break;
default:
ACE_ERROR ((LM_ERROR,
- "Usage: Thread_Pool_Reactor_Test [-r <hostname:port#>]"
+ "Usage: Thread_Pool_Reactor_SSL_Test [-r <hostname:port#>]"
"\t[-s <server thr#>] [-c <client thr#>] [-d <delay>]"
"\t[-i <client conn attempt#>]"
"[-n <client request# per conn>]\n"));
diff --git a/ACE/tests/SSL/Thread_Pool_Reactor_SSL_Test.h b/ACE/tests/SSL/Thread_Pool_Reactor_SSL_Test.h
index 64f251f2f62..6d96043f40f 100644
--- a/ACE/tests/SSL/Thread_Pool_Reactor_SSL_Test.h
+++ b/ACE/tests/SSL/Thread_Pool_Reactor_SSL_Test.h
@@ -11,7 +11,6 @@
*/
//=============================================================================
-
#ifndef ACE_TESTS_THREAD_POOL_REACTOR_TEST_SSL_H
#define ACE_TESTS_THREAD_POOL_REACTOR_TEST_SSL_H
@@ -23,11 +22,10 @@
#include "ace/Svc_Handler.h"
+/// This class is the Svc_Handler used by <Acceptor>.
class Request_Handler : public ACE_Svc_Handler<ACE_SSL_SOCK_Stream,
ACE_MT_SYNCH>
{
- // = TITLE
- // This class is the Svc_Handler used by <Acceptor>.
public:
/// The default constructor makes sure the right reactor is used.
Request_Handler (ACE_Thread_Manager *tm = 0);
@@ -37,7 +35,7 @@ protected:
virtual int handle_close (ACE_HANDLE fd, ACE_Reactor_Mask = 0);
private:
- size_t nr_msgs_rcvd_;
+ size_t nr_msgs_rcvd_;
};
#endif /* ACE_TESTS_THREAD_POOL_REACTOR_TEST_SSL_H */
diff --git a/ACE/tests/tests.mpc b/ACE/tests/tests.mpc
index 1b4b2324ea6..f604aa67a8b 100644
--- a/ACE/tests/tests.mpc
+++ b/ACE/tests/tests.mpc
@@ -614,15 +614,6 @@ project(Compiler_Features_07_Test) : acetest {
}
}
-// This compiler feature is not supported on all compilers
-project(Compiler_Features_08_Test) : acetest {
- requires += dummy_label
- exename = Compiler_Features_08_Test
- Source_Files {
- Compiler_Features_08_Test.cpp
- }
-}
-
project(Compiler_Features_09_Test) : acetest {
exename = Compiler_Features_09_Test
Source_Files {
diff --git a/TAO/PROBLEM-REPORT-FORM b/TAO/PROBLEM-REPORT-FORM
index 9dd10200a8b..95190651d64 100644
--- a/TAO/PROBLEM-REPORT-FORM
+++ b/TAO/PROBLEM-REPORT-FORM
@@ -2,19 +2,19 @@
reports, etc., to the TAO developers and interested users.
Send it to tao-bugs@list.isis.vanderbilt.edu, you must be subscribed
to the list in order to be able to post to it. If you are using OCI
- or PrismTech's versions of TAO do not send bugs to this mailing list, but
+ or MicroFocus's versions of TAO do not send bugs to this mailing list, but
instead contact those companies for support. Please also send your
PRF as plain ASCII text, _not_ uuencoded or as an attachment.
- We prefer that all bug reports be submitted through our bug tracking
- system. See $ACE_ROOT/docs/usage-bugzilla.html for more information
+ We prefer that all bug reports be submitted through github issues.
+ See https://github.com/DOCGroup/ACE_TAO/issues for more information
about how to do this. If you are unsure as to whether your problem
is a real bug or not then please submit your question to the mailing
list using the following form. Not using the problem report form
will make it harder or impossible to identify the problem, and in
many cases we will be unable to help at all. Also please try to
- browse bugzilla and the ChangeLog files to find out if your problem
- has been solved in a more recent version of TAO.
+ browse the existing github isssues and the ChangeLog files to find
+ out if your problem has been solved in a more recent version of TAO.
To subscribe to the list see
https://www.dre.vanderbilt.edu/~schmidt/ACE-mail.html
diff --git a/TAO/TAO-INSTALL.html b/TAO/TAO-INSTALL.html
index 3b3970d2f8a..a13c716489f 100644
--- a/TAO/TAO-INSTALL.html
+++ b/TAO/TAO-INSTALL.html
@@ -534,7 +534,7 @@ quickly.
<LI>Please make sure that you have <a href="http://www.perl.org">
perl</a> installed, preferably perl
5.8 or higher. Users on Win32 based platforms are recommended to use
- <a href="http://www.activestate.com/Products/ActivePerl/"> Active
+ <a href="https://www.activestate.com/products/perl"> Active
State Perl </a>. We use active state perl without problems. We have
ran into problems trying to use the cygwin version of perl on Win32
based platforms.</LI><p/>
diff --git a/TAO/TAO_IDL/util/utl_global.cpp b/TAO/TAO_IDL/util/utl_global.cpp
index 2c60a64869b..f6e2c828126 100644
--- a/TAO/TAO_IDL/util/utl_global.cpp
+++ b/TAO/TAO_IDL/util/utl_global.cpp
@@ -1930,64 +1930,82 @@ struct yy_buffer_state;
extern yy_buffer_state *tao_yy_scan_string (const char *);
extern int tao_yylex_destroy ();
+namespace
+{
+ class OldState
+ {
+ public:
+ explicit OldState (bool disable_output = false)
+ : old_filename_ (idl_global->filename ()),
+ old_lineno_ (idl_global->lineno ()),
+ old_idl_src_file_ (idl_global->idl_src_file ()),
+ disable_output_ (disable_output),
+ flags_ (ACE_LOG_MSG->flags ())
+ {
+ idl_global->in_eval_ = true;
+
+ idl_global->set_lineno (1);
+ idl_global->set_filename (0);
+
+ // Name this pseudo-file "builtin-N"
+ static char buffer[64];
+ static unsigned n = 1;
+ ACE_OS::snprintf (&buffer[0], sizeof buffer, "builtin-%u", n++);
+ UTL_String utl_string (&buffer[0], true);
+ idl_global->idl_src_file (new UTL_String (&utl_string, true));
+ idl_global->set_filename (new UTL_String (&utl_string, true));
+
+ if (disable_output_)
+ {
+ default_streambuf_ = ACE_DEFAULT_LOG_STREAM->rdbuf ();
+ ACE_DEFAULT_LOG_STREAM->rdbuf (0);
+ ACE_LOG_MSG->clr_flags (ACE_Log_Msg::STDERR);
+ ACE_LOG_MSG->clr_flags (ACE_LOG_MSG->flags ());
+ }
+ }
+
+ ~OldState()
+ {
+ idl_global->set_lineno (old_lineno_);
+
+ idl_global->set_filename (old_filename_);
+ idl_global->idl_src_file ()->destroy ();
+ delete idl_global->idl_src_file ();
+ idl_global->idl_src_file (old_idl_src_file_);
+ idl_global->reset_flag_seen ();
+
+ if (disable_output_)
+ {
+ ACE_DEFAULT_LOG_STREAM->rdbuf (default_streambuf_);
+ ACE_LOG_MSG->set_flags (flags_);
+ }
+
+ tao_yylex_destroy ();
+ idl_global->in_eval_ = false;
+ }
+
+ private:
+ UTL_String *old_filename_;
+ long old_lineno_;
+ UTL_String *old_idl_src_file_;
+ bool disable_output_;
+ std::streambuf *default_streambuf_;
+ const unsigned long flags_;
+ };
+}
+
void
IDL_GlobalData::eval (const char *string, bool disable_output)
{
- in_eval_ = true;
-
- // Get IDL_Global Context
- UTL_String *old_filename = filename ();
- pd_filename = 0;
- long old_lineno = lineno ();
- idl_global->set_lineno (1);
- UTL_String *old_idl_src_file = idl_src_file ();
-
- // Name this pseudo-file "builtin-N"
-#define BUILTIN_NAME_BUFFER_SIZE 64
- static char buffer[BUILTIN_NAME_BUFFER_SIZE];
- static unsigned n = 1;
- ACE_OS::snprintf (&buffer[0], BUILTIN_NAME_BUFFER_SIZE, "builtin-%u", n++);
-#undef BUILTIN_NAME_BUFFER_SIZE
- UTL_String utl_string (&buffer[0], true);
- idl_global->idl_src_file (new UTL_String (&utl_string, true));
- idl_global->set_filename (new UTL_String (&utl_string, true));
+ OldState old (disable_output);
// Set up Flex to read from string
tao_yy_scan_string (string);
- // Disable Output
- std::streambuf *default_streambuf = ACE_DEFAULT_LOG_STREAM->rdbuf ();
- const unsigned long flags = ACE_LOG_MSG->flags ();
- if (disable_output)
- {
- ACE_DEFAULT_LOG_STREAM->rdbuf (0);
- ACE_LOG_MSG->clr_flags (ACE_Log_Msg::STDERR);
- }
-
// emulate DRV_drive()
FE_yyparse ();
idl_global->check_primary_keys ();
AST_check_fwd_decls ();
-
- // Renable Output
- if (disable_output)
- {
- ACE_DEFAULT_LOG_STREAM->rdbuf (default_streambuf);
- ACE_LOG_MSG->set_flags (flags);
- }
-
- // Have Flex Cleanup
- tao_yylex_destroy ();
-
- // Restore IDL_Global Context
- idl_global->set_filename (old_filename);
- idl_src_file()->destroy ();
- delete idl_src_file ();
- idl_src_file (old_idl_src_file);
- idl_global->set_lineno (old_lineno);
- idl_global->reset_flag_seen ();
-
- in_eval_ = false;
}
void
diff --git a/TAO/orbsvcs/orbsvcs/SSLIOP/SSLIOP_Factory.cpp b/TAO/orbsvcs/orbsvcs/SSLIOP/SSLIOP_Factory.cpp
index 6cea0ee37ed..907e7246983 100644
--- a/TAO/orbsvcs/orbsvcs/SSLIOP/SSLIOP_Factory.cpp
+++ b/TAO/orbsvcs/orbsvcs/SSLIOP/SSLIOP_Factory.cpp
@@ -336,7 +336,7 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, ACE_TCHAR* argv[])
? SSL_MAX_SSL_SESSION_ID_LENGTH
: sizeof session_id_context_;
- // Note that this function returns 1, if the operation succeded.
+ // Note that this function returns 1, if the operation succeeded.
// See SSL_CTX_set_session_id_context(3)
if( 1 != ::SSL_CTX_set_session_id_context (ssl_ctx->context(),
session_id_context_,
diff --git a/TAO/orbsvcs/tests/Concurrency/CC_command.tab.cpp b/TAO/orbsvcs/tests/Concurrency/CC_command.tab.cpp
index 7fbc5c0a2af..1aa29d910f3 100644
--- a/TAO/orbsvcs/tests/Concurrency/CC_command.tab.cpp
+++ b/TAO/orbsvcs/tests/Concurrency/CC_command.tab.cpp
@@ -386,7 +386,7 @@ __ace_cc_yy_memcpy (to, from, count)
char *from;
unsigned int count;
{
- register char *f = from;
+ char *f = from;
register char *t = to;
register int i = count;
diff --git a/TAO/orbsvcs/tests/Concurrency/lex.CC_command.cpp b/TAO/orbsvcs/tests/Concurrency/lex.CC_command.cpp
index 6d74bf08cae..ac1562263fb 100644
--- a/TAO/orbsvcs/tests/Concurrency/lex.CC_command.cpp
+++ b/TAO/orbsvcs/tests/Concurrency/lex.CC_command.cpp
@@ -604,9 +604,9 @@ ACE_CC_YY_MALLOC_DECL
ACE_CC_YY_DECL
{
- register ace_cc_yy_state_type ace_cc_yy_current_state;
- register char *ace_cc_yy_cp = 0, *ace_cc_yy_bp = 0;
- register int ace_cc_yy_act;
+ ace_cc_yy_state_type ace_cc_yy_current_state;
+ char *ace_cc_yy_cp = 0, *ace_cc_yy_bp = 0;
+ int ace_cc_yy_act;
@@ -654,7 +654,7 @@ ACE_CC_YY_DECL
ace_cc_yy_match:
do
{
- register ACE_CC_YY_CHAR ace_cc_yy_c = ace_cc_yy_ec[ACE_CC_YY_SC_TO_UI(*ace_cc_yy_cp)];
+ ACE_CC_YY_CHAR ace_cc_yy_c = ace_cc_yy_ec[ACE_CC_YY_SC_TO_UI(*ace_cc_yy_cp)];
if ( ace_cc_yy_accept[ace_cc_yy_current_state] )
{
ace_cc_yy_last_accepting_state = ace_cc_yy_current_state;
@@ -947,9 +947,9 @@ case ACE_CC_YY_STATE_EOF(INITIAL):
static int ace_cc_yy_get_next_buffer()
{
- register char *dest = ace_cc_yy_current_buffer->ace_cc_yy_ch_buf;
- register char *source = ace_cc_yytext_ptr;
- register int number_to_move, i;
+ char *dest = ace_cc_yy_current_buffer->ace_cc_yy_ch_buf;
+ char *source = ace_cc_yytext_ptr;
+ int number_to_move, i;
int ret_val;
if ( ace_cc_yy_c_buf_p > &ace_cc_yy_current_buffer->ace_cc_yy_ch_buf[ace_cc_yy_n_chars + 1] )
@@ -1079,15 +1079,15 @@ static int ace_cc_yy_get_next_buffer()
static ace_cc_yy_state_type ace_cc_yy_get_previous_state()
{
- register ace_cc_yy_state_type ace_cc_yy_current_state;
- register char *ace_cc_yy_cp;
+ ace_cc_yy_state_type ace_cc_yy_current_state;
+ char *ace_cc_yy_cp;
ace_cc_yy_current_state = ace_cc_yy_start;
ace_cc_yy_current_state += ACE_CC_YY_AT_BOL();
for ( ace_cc_yy_cp = ace_cc_yytext_ptr + ACE_CC_YY_MORE_ADJ; ace_cc_yy_cp < ace_cc_yy_c_buf_p; ++ace_cc_yy_cp )
{
- register ACE_CC_YY_CHAR ace_cc_yy_c = (*ace_cc_yy_cp ? ace_cc_yy_ec[ACE_CC_YY_SC_TO_UI(*ace_cc_yy_cp)] : 1);
+ ACE_CC_YY_CHAR ace_cc_yy_c = (*ace_cc_yy_cp ? ace_cc_yy_ec[ACE_CC_YY_SC_TO_UI(*ace_cc_yy_cp)] : 1);
if ( ace_cc_yy_accept[ace_cc_yy_current_state] )
{
ace_cc_yy_last_accepting_state = ace_cc_yy_current_state;
@@ -1119,10 +1119,10 @@ static ace_cc_yy_state_type ace_cc_yy_try_NUL_trans( ace_cc_yy_current_state )
ace_cc_yy_state_type ace_cc_yy_current_state;
#endif
{
- register int ace_cc_yy_is_jam;
- register char *ace_cc_yy_cp = ace_cc_yy_c_buf_p;
+ int ace_cc_yy_is_jam;
+ char *ace_cc_yy_cp = ace_cc_yy_c_buf_p;
- register ACE_CC_YY_CHAR ace_cc_yy_c = 1;
+ ACE_CC_YY_CHAR ace_cc_yy_c = 1;
if ( ace_cc_yy_accept[ace_cc_yy_current_state] )
{
ace_cc_yy_last_accepting_state = ace_cc_yy_current_state;
@@ -1143,14 +1143,14 @@ ace_cc_yy_state_type ace_cc_yy_current_state;
#ifndef ACE_CC_YY_NO_UNPUT
#ifdef ACE_CC_YY_USE_PROTOS
-static void ace_cc_yyunput( int c, register char *ace_cc_yy_bp )
+static void ace_cc_yyunput( int c, char *ace_cc_yy_bp )
#else
static void ace_cc_yyunput( c, ace_cc_yy_bp )
int c;
-register char *ace_cc_yy_bp;
+char *ace_cc_yy_bp;
#endif
{
- register char *ace_cc_yy_cp = ace_cc_yy_c_buf_p;
+ char *ace_cc_yy_cp = ace_cc_yy_c_buf_p;
/* undo effects of setting up ace_cc_yytext */
*ace_cc_yy_cp = ace_cc_yy_hold_char;
@@ -1158,10 +1158,10 @@ register char *ace_cc_yy_bp;
if ( ace_cc_yy_cp < ace_cc_yy_current_buffer->ace_cc_yy_ch_buf + 2 )
{ /* need to shift things up to make room */
/* +2 for EOB chars. */
- register int number_to_move = ace_cc_yy_n_chars + 2;
- register char *dest = &ace_cc_yy_current_buffer->ace_cc_yy_ch_buf[
+ int number_to_move = ace_cc_yy_n_chars + 2;
+ char *dest = &ace_cc_yy_current_buffer->ace_cc_yy_ch_buf[
ace_cc_yy_current_buffer->ace_cc_yy_buf_size + 2];
- register char *source =
+ char *source =
&ace_cc_yy_current_buffer->ace_cc_yy_ch_buf[number_to_move];
while ( source > ace_cc_yy_current_buffer->ace_cc_yy_ch_buf )
@@ -1621,7 +1621,7 @@ ace_cc_yyconst char *s2;
int n;
#endif
{
- register int i;
+ int i;
for ( i = 0; i < n; ++i )
s1[i] = s2[i];
}
@@ -1635,7 +1635,7 @@ static int ace_cc_yy_flex_strlen( s )
ace_cc_yyconst char *s;
#endif
{
- register int n;
+ int n;
for ( n = 0; s[n]; ++n )
;
diff --git a/azure-pipelines.yml b/azure-pipelines.yml
index ff4f858b1be..ddb7e953ffa 100644
--- a/azure-pipelines.yml
+++ b/azure-pipelines.yml
@@ -171,100 +171,3 @@ jobs:
platform: $(BuildPlatform)
configuration: $(BuildConfiguration)
maximumCpuCount: true
-
-- job: Linux
- timeoutInMinutes: 90
- pool:
- vmImage: ubuntu-18.04
- strategy:
- matrix:
- CLANG5:
- CC: clang-5.0
- CXX: clang++-5.0
- PackageDeps: clang-5.0
- platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux_clang.GNU
- CLANG6:
- CC: clang-6.0
- CXX: clang++-6.0
- PackageDeps: clang-6.0
- platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux_clang.GNU
- CLANG7:
- CC: clang-7
- CXX: clang++-7
- PackageDeps: clang-7
- platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux_clang.GNU
- CLANG8:
- CC: clang-8
- CXX: clang++-8
- PackageDeps: clang-8
- platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux_clang.GNU
- CLANG9:
- CC: clang-9
- CXX: clang++-9
- PackageDeps: clang-9
- Repo: llvm-toolchain-$(lsb_release -cs)-9
- platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux_clang.GNU
- CLANG10:
- CC: clang-10
- CXX: clang++-10
- PackageDeps: clang-10
- Repo: llvm-toolchain-$(lsb_release -cs)-10
- platform_file: include $(ACE_ROOT)/include/makeinclude/platform_linux_clang.GNU
- steps:
- - script: |
- wget -O - https://apt.llvm.org/llvm-snapshot.gpg.key|sudo apt-key add -
- sudo apt-add-repository "deb http://apt.llvm.org/$(lsb_release -cs)/ $(Repo) main"
- displayName: Add repository ($(Repo))
- condition: and(succeeded(), ne(variables['Repo'], ''))
- - script: |
- sudo apt-get --yes update
- sudo apt-get --yes install libxerces-c-dev libssl-dev $(PackageDeps)
- displayName: install system package dependencies
- - powershell: |
- '#include "ace/config-linux.h"' > $(ACE_ROOT)/ace/config.h
- displayName: Create config.h file
- - powershell: |
- 'xerces3=1' > $(ACE_ROOT)/bin/MakeProjectCreator/config/default.features
- 'ssl=1' >> $(ACE_ROOT)/bin/MakeProjectCreator/config/default.features
- 'ipv6=1' >> $(ACE_ROOT)/bin/MakeProjectCreator/config/default.features
- 'versioned_namespace=1' >> $(ACE_ROOT)/bin/MakeProjectCreator/config/default.features
- displayName: Create default.features file
- - powershell: |
- 'c++11=1' > $(ACE_ROOT)/include/makeinclude/platform_macros.GNU
- 'xerces3=1' >> $(ACE_ROOT)/include/makeinclude/platform_macros.GNU
- 'ssl=1' >> $(ACE_ROOT)/include/makeinclude/platform_macros.GNU
- 'ipv6=1' >> $(ACE_ROOT)/include/makeinclude/platform_macros.GNU
- "$(platform_file)" >> $(ACE_ROOT)/include/makeinclude/platform_macros.GNU
- displayName: Create platform_macros file
- - powershell: git clone --depth 1 git://github.com/DOCGroup/MPC.git $(MPC_ROOT)
- displayName: git clone MPC
- - powershell: perl $(ACE_ROOT)/bin/mwc.pl -type gnuace $(TAO_ROOT)/TAO_ACE.mwc -workers 4
- displayName: Run mwc.pl on $(TAO_ROOT)/TAO_ACE.mwc
- - powershell: perl $(ACE_ROOT)/bin/mwc.pl -type gnuace $(ACE_ROOT)/tests/tests.mwc -workers 4
- displayName: Run mwc.pl on $(ACE_ROOT)/tests/tests.mwc
- - bash: make -j 6 -C TAO
- displayName: Build TAO project
- - bash: make -j 6 -C ACE/tests
- displayName: Build tests project
-
-- job: MacOSX
- timeoutInMinutes: 90
- pool:
- vmImage: macOS-latest
- steps:
- - powershell: |
- '#include "ace/config-macosx.h"' > $(ACE_ROOT)/ace/config.h
- displayName: Create config.h file
- - powershell: |
- 'include $(ACE_ROOT)/include/makeinclude/platform_macosx.GNU' > $(ACE_ROOT)/include/makeinclude/platform_macros.GNU;
- displayName: Create platform_macros file
- - powershell: git clone --depth 1 git://github.com/DOCGroup/MPC.git $(MPC_ROOT)
- displayName: git clone MPC
- - powershell: perl $(ACE_ROOT)/bin/mwc.pl -type gnuace $(TAO_ROOT)/TAO_ACE.mwc -workers 4
- displayName: Run mwc.pl on $(TAO_ROOT)/TAO_ACE.mwc
- - powershell: perl $(ACE_ROOT)/bin/mwc.pl -type gnuace $(ACE_ROOT)/tests/tests.mwc -workers 4
- displayName: Run mwc.pl on $(ACE_ROOT)/tests/tests.mwc
- - bash: make -j 6 -C TAO
- displayName: Build TAO project
- - bash: make -j 6 -C ACE/tests
- displayName: Build tests project
diff --git a/ACE/tests/Compiler_Features_13_Test.cpp b/ACE/tests/Compiler_Features_13_Test.cpp
index 61dd46be09a..15308dc8af3 100644
--- a/ACE/tests/Compiler_Features_13_Test.cpp
+++ b/ACE/tests/Compiler_Features_13_Test.cpp
@@ -1,6 +1,4 @@
/**
- * @file
- *
* This program checks if the compiler / platform supports the
* standard cast operators template parameters. The motivation for
* this test was a discussion on the development mailing list, and the
@@ -12,6 +10,7 @@
#include "test_config.h"
#include <stdexcept>
+#include <typeinfo>
namespace
{
@@ -42,7 +41,6 @@ namespace
};
}
-
int
run_main (int, ACE_TCHAR *[])
{
@@ -103,7 +101,7 @@ run_main (int, ACE_TCHAR *[])
ACE_TEXT("dynamic_cast should return null\n")));
}
// Make sure dynamic cast raises an exception
Base & b3 = a;
try
{
@@ -111,16 +109,16 @@ run_main (int, ACE_TCHAR *[])
status = 1;
ACE_ERROR((LM_ERROR,
- ACE_TEXT("dynamic_cast should have raised exception\n")));
+ ACE_TEXT("dynamic_cast should have raised std::bad_cast\n")));
}
- catch(std::exception const &)
+ catch(std::bad_cast const &)
{
}
catch(...)
{
status = 1;
ACE_ERROR((LM_ERROR,
- ACE_TEXT("dynamic_cast should have raised std::exception\n")));
+ ACE_TEXT("dynamic_cast should have raised std::bad_cast\n")));
}
{
@@ -140,4 +138,3 @@ run_main (int, ACE_TCHAR *[])
ACE_END_TEST;
return status;
}
-
@@ -103,7 +101,7 @@ run_main (int, ACE_TCHAR *[])
ACE_TEXT("dynamic_cast should return null\n")));
}
- // Make sure dynamic cast raises an exception
+ // Make sure dynamic cast raises a bad_cast exception
Base & b3 = a;
try